Flutter advance util

This package contains animations which are all from the Flutter advance project by Tomiwa Idowu. The main aim of the package is to make implementing already built animations simple to implement in virtually every flutter app.

Features

🔐 Flutter Advance GitHub stars

Feel free to star, fork and contribute.

🤓 Developer

Tomiwa Idowu

Pending implementation

Beta implementations

Usage

To use simply import the package

import 'package:flutter_advance_util/flutter_advance_util.dart';

Additional information

🤓 Developer

Adeboye Iremide

Twitter linkedin