AnimatedCard class

Inheritance

Constructors

AnimatedCard({Key? key, required Color activeColor, Color? inactiveColor, required Widget icon, required String detail, required String actionText, VoidCallback? action, required double height, required double width, Color? shadowColor, Offset shadowPosition = const Offset(0, 3), double? spacing, EdgeInsets padding = const EdgeInsets.symmetric(horizontal: 20, vertical: 20), Size? iconSize, Color activeTextColor = Colors.white, Color inactiveTextColor = Colors.black, double borderRadius = 10, FontWeight actionFontWeight = FontWeight.w500, FontWeight detailFontWeight = FontWeight.w600, Alignment actionAlignment = Alignment.bottomRight})
A simple animated card that changes color upon user interaction. Useful for displaying information a creative way but could be made to execute a function by setting the action parameter.
const

Properties

action VoidCallback?
action to perform upon user interaction with the actionText.
final
actionAlignment Alignment
final
actionFontWeight FontWeight
final
actionText String
Text to display at the bottom of the card.
final
activeColor Color
final
activeTextColor Color
final
borderRadius double
final
detail String
Text to display in the middle of the card.
final
detailFontWeight FontWeight
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
icon Widget
final
iconSize Size?
final
inactiveColor Color?
final
inactiveTextColor Color
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadowColor Color?
final
shadowPosition Offset
final
spacing double?
final
width double
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<AnimatedCard>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited