PetalMenu class

A simple flower petals animation.

Inheritance

Constructors

PetalMenu({Key? key, required List<Petal> petals, BoxFit? fit, required int initialIndex, HitTestBehavior? behavior, Duration delay = const Duration(milliseconds: 250), Duration duration = const Duration(milliseconds: 250), double? height, double? width})
A simple flower petals animation.
const

Properties

behavior HitTestBehavior?
Hit behaviour of each petal.
final
delay Duration
Duration of delay after user action, default 250ms
final
duration Duration
Duration of animation, default 250ms.
final
fit BoxFit?
FittedBox behaviour of child widget in each petal.
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
initialIndex int
Starting option of petals.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
petals List<Petal>
A list of Petals. At least one petal.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<PetalMenu>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited